<?php

namespace VerifoneEcomAPI\ApiWrapper\Http\ApiClient;

use VerifoneEcomAPI\ApiWrapper\Authentication\Interfaces\AuthenticationInterface;
use VerifoneEcomAPI\ApiWrapper\Http\HttpException;
use VerifoneEcomAPI\ApiWrapper\Http\SimpleCurl;
use VerifoneEcomAPI\ApiWrapper\Regions\AbstractRegion;
use VerifoneEcomAPI\ApiWrapper\Settings;

/**
 * Class Client
 * @package VerifoneEcomAPI\ApiWrapper\Http\ApiClient
 */
class Client {

    private $region;
    private $simpleCurl;
    private $settings;
    private $authentication;
    private $auth;

    /**
     * Client constructor.
     *
     * @param AbstractRegion $region
     * @param Settings $settings
     * @param AuthenticationInterface $authentication
     * @param SimpleCurl $simpleCurl
     */
    public function __construct(
        AbstractRegion $region,
        Settings $settings,
        AuthenticationInterface $authentication,
        SimpleCurl $simpleCurl
    ) {
        $this->region         = $region;
        $this->authentication = $authentication;
        $this->settings       = $settings;
        $this->simpleCurl     = $simpleCurl;
        $this->auth           = $this->authentication->getAuth();
    }

    /**
     * @param array $payload
     * @param $transactionId
   
     *
     * @return mixed
     * @throws HttpException
     */
    public function postCapture( array $payload, $transactionId) {
       

        $result = $this->simpleCurl->setOpt( CURLOPT_URL, $this->region->postCaptureUrl( $transactionId ) )
                                   ->setOpt( CURLOPT_RETURNTRANSFER, true )
                                   ->setOpt( CURLOPT_POST, true )
                                   ->setOpt( CURLOPT_POSTFIELDS, json_encode( $payload ) )
                                   ->setOpt( CURLOPT_HTTPHEADER, $this->getHeaders() );
        $this->addSsl( $result );

        return $this->decodeResult( $result->getResult() );
    }

    /**
     * @param array $payload
     *
     * @return mixed
     * @throws HttpException
     */
    public function postSubscription( array $payload ) {

        $result = $this->simpleCurl->setOpt( CURLOPT_URL, $this->region->postSubscriptionUrl() )
                                   ->setOpt( CURLOPT_RETURNTRANSFER, true )
                                   ->setOpt( CURLOPT_POST, true )
                                   ->setOpt( CURLOPT_POSTFIELDS, json_encode( $payload ) )
                                   ->setOpt( CURLOPT_HTTPHEADER, $this->getHeaders() );
        $this->addSsl( $result );

        return $this->decodeResult( $result->getResult() );
    }

    /**
     * @param array $payload
     * @param $transactionId
   
     *
     * @return mixed
     * @throws HttpException
     */
    public function postPaypalCapture( array $payload, $transactionId) {
       

        $result = $this->simpleCurl->setOpt( CURLOPT_URL, $this->region->postPaypalCaptureUrl( $transactionId ) )
                                   ->setOpt( CURLOPT_RETURNTRANSFER, true )
                                   ->setOpt( CURLOPT_POST, true )
                                   ->setOpt( CURLOPT_POSTFIELDS, json_encode( $payload ) )
                                   ->setOpt( CURLOPT_HTTPHEADER, $this->getHeaders() );
        $this->addSsl( $result );

        return $this->decodeResult( $result->getResult() );
    }

    /**
     * @param array $payload
     * @param $transactionId
   
     *
     * @return mixed
     * @throws HttpException
     */
    public function postVoidAuthorization( array $payload, $transactionId) {
       

        $result = $this->simpleCurl->setOpt( CURLOPT_URL, $this->region->postVoidAuthorizationUrl( $transactionId ) )
                                   ->setOpt( CURLOPT_RETURNTRANSFER, true )
                                   ->setOpt( CURLOPT_POST, true )
                                   ->setOpt( CURLOPT_POSTFIELDS, json_encode( $payload ) )
                                   ->setOpt( CURLOPT_HTTPHEADER, $this->getHeaders() );
        $this->addSsl( $result );

        return $this->decodeResult( $result->getResult() );
    }

    /**
     * @param array $payload
   
     *
     * @return mixed
     * @throws HttpException
     */
    public function postCustomer( array $payload) {
       

        $result = $this->simpleCurl->setOpt( CURLOPT_URL, $this->region->postCustomerUrl() )
                                   ->setOpt( CURLOPT_RETURNTRANSFER, true )
                                   ->setOpt( CURLOPT_POST, true )
                                   ->setOpt( CURLOPT_POSTFIELDS, json_encode( $payload ) )
                                   ->setOpt( CURLOPT_HTTPHEADER, $this->getHeaders() );
        $this->addSsl( $result );

        return $this->decodeResult( $result->getResult() );
    }

    /**
     * @param array $payload
     *
     * @return mixed
     * @throws HttpException
     * @throws \Exception
     */
    public function postCheckout( array $payload ) {
        $result = $this->simpleCurl->setOpt( CURLOPT_URL, $this->region->postCheckoutUrl() )
                                   ->setOpt( CURLOPT_RETURNTRANSFER, true )
                                   ->setOpt( CURLOPT_POST, true )
                                   ->setOpt( CURLOPT_POSTFIELDS, json_encode( $payload ) )
                                   ->setOpt( CURLOPT_HTTPHEADER, $this->getHeaders() );
        $this->addSsl( $result );

        return $this->decodeResult( $result->getResult() );
    }

    /**
     * @param array $payload
     * @param $transactionId
     *
     * @return mixed
     * @throws HttpException
     * @throws \Exception
     */
    public function postRefund( array $payload, $transactionId) {

        $result = $this->simpleCurl->setOpt( CURLOPT_URL, $this->region->getRefundUrl( $transactionId ) )
                                   ->setOpt( CURLOPT_RETURNTRANSFER, true )
                                   ->setOpt( CURLOPT_POST, true )
                                   ->setOpt( CURLOPT_POSTFIELDS, json_encode( $payload ) )
                                   ->setOpt( CURLOPT_HTTPHEADER, $this->getHeaders() );
        $this->addSsl( $result );

        return $this->decodeResult( $result->getResult() );
    }

    /**
     * @param array $payload
     * @param $transactionId
     *
     * @return mixed
     * @throws HttpException
     * @throws \Exception
     */
    public function postPaypalRefund( array $payload, $transactionId ) {

        $result = $this->simpleCurl->setOpt( CURLOPT_URL, $this->region->getRefundPaypalUrl( $transactionId ) )
                                   ->setOpt( CURLOPT_RETURNTRANSFER, true )
                                   ->setOpt( CURLOPT_POST, true )
                                   ->setOpt( CURLOPT_POSTFIELDS, json_encode( $payload ) )
                                   ->setOpt( CURLOPT_HTTPHEADER, $this->getHeaders() );
        $this->addSsl( $result );

        return $this->decodeResult( $result->getResult() );
    }

    /**
     * @param $checkoutId
     *
     * @return mixed
     * @throws HttpException
     */
    public function getCheckout( $checkoutId ) {
        $result = $this->simpleCurl->setOpt( CURLOPT_URL, $this->region->getCheckoutUrl( $checkoutId ) )
                                   ->setOpt( CURLOPT_RETURNTRANSFER, true )
                                   ->setOpt( CURLOPT_HTTPHEADER, $this->getHeaders() );
        $this->addSsl( $result );

        return $this->decodeResult( $result->getResult() );
    }

    /**
     * @param $transactionId
     *
     * @return mixed
     * @throws HttpException
     */
    public function getTransaction( $transactionId ) {
        $result = $this->simpleCurl->setOpt( CURLOPT_URL, $this->region->getTransactionUrl( $transactionId ) )
                                   ->setOpt( CURLOPT_RETURNTRANSFER, true )
                                   ->setOpt( CURLOPT_HTTPHEADER, $this->getHeaders() );
        $this->addSsl( $result );

        return $this->decodeResult( $result->getResult() );
    }

    /**
     * @param $client
     */
    private function addSsl( $client ) {
        if ( ! $this->settings->getCurlVerifySsl() ) {
            $client->setOpt( CURLOPT_SSL_VERIFYHOST, false )
                   ->setOpt( CURLOPT_SSL_VERIFYPEER, false );
        }
    }

    /**
     * @return string[]
     */
    private function getHeaders() {
        return [
            'Content-Type: application/json',
            'Authorization: Basic ' . $this->auth,
        ];
    }


    /**
     * @param $result
     *
     * @return mixed
     * @throws HttpException
     */
    private function decodeResult( $result ) {
        $result = json_decode( $result, true );
        if ( json_last_error() !== JSON_ERROR_NONE ) {
            throw new HttpException( 'Unable to decode response from API' );
        }

        return $result;
    }
}