<?php

use VerifoneEcomAPI\ApiWrapper\Authentication\Interfaces\AuthenticationInterface;
use VerifoneEcomAPI\ApiWrapper\Authentication\TokenGenerator;

class Verifone_Hosted_Auth_Helper implements AuthenticationInterface {
    /**
     * @var AuthenticationInterface
     */
    private $authentication;

    /**
     * The token is stored along with the expiration time in the meta data
     * To get it back and to check the exp time we use a "divider" and explode the string
     */
    const VERIFONE_TOKEN_SPLITTER = '___EXPIRE___';

    public function __construct( AuthenticationInterface $authentication ) {
        $this->authentication = $authentication;
    }

    public function getAuth() {
        if ( $this->authentication instanceof TokenGenerator ) {
            // get the token if it already exists
            // in case in doesn't it will continue execution
            // ttl is gotten from the decoded token itself
            // rather than setting a hardcoded value
            $token = get_option( '__verifone_api_token' );
            if ( ! $token ) {
                $token = $this->authentication->getAuth();
                // invalidate the token 5 minutes before it actually expires
                $ttl = intval( $this->authentication->getTokenProperty( $token, 'expires_in' ) ) - 300;

                // initial call for set value, this will only be called once
                // since even if the token is expired it will still exist as an option
                // If the option does not exist, it will be created
                update_option( '__verifone_api_token', $token . self::VERIFONE_TOKEN_SPLITTER . ( time() + $ttl ) );

                return $token;
            }

            $split      = explode( self::VERIFONE_TOKEN_SPLITTER, $token );
            $expiration = intval( $split[1] );
            // check if token is still valid
            if ( time() < $expiration ) {
                return trim( $split[0] );
            }

            $token = $this->authentication->getAuth();
            // invalidate the token 5 minutes before it actually expires
            $ttl = intval( $this->authentication->getTokenProperty( $token, 'expires_in' ) ) - 300;
            update_option( '__verifone_api_token', $token . self::VERIFONE_TOKEN_SPLITTER . ( time() + $ttl ) );

            return trim( $token );
        }
    }
}
