<?php

/**
 * @return array[]
 */
function getVerifoneHostedCartVerifoneAccountSettingsFields() {
    return [
        'account_settings' => [
            'title' => __( 'Verifone account settings', 'verifone-hosted' ),
            'type'  => 'title',
        ],
        'test'             => [
            'title'       => __( 'Enable test mode', 'verifone-hosted' ),
            'type'        => 'checkbox',
            'description' => __( 'Use the Verifone testing environment (CST) to test the integration, if you have an account set up in the CST environment.', 'verifone-hosted' ),
            'label'       => __( 'Enable test mode', 'verifone-hosted' ),
            'default'     => 'yes',
            'desc_tip'    => true,
        ],
        'user_id'          => [
            'title'       => __( 'User ID', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'The user id of the user that generated the API Key in Verifone Central. You can find it in your Verifone Central account, under Profile → API Keys. (mandatory)', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => '',
        ],
        'api_key'          => [
            'title'       => __( 'API Key', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'The value of the public API Key you created in Verifone Central. (mandatory)', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => '',
        ],
        'entity_id'        => [
            'title'       => __( 'Organisation ID', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'The organisation ID can be found in Verifone Central, under Administration → Organisations.', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => '',
        ],
        'region'           => [
            'title'       => __( 'Verifone account region', 'verifone-hosted' ),
            'type'        => 'select',
            'description' => __( 'The region in which your Verifone account is created. Check your Verifone Central access URL if in doubt.', 'verifone-hosted' ),
            'label'       => __( 'Verifone account region', 'verifone-hosted' ),
            'options'     => [
                'EMEA' => 'EMEA (Europe, Middle East, Africa)',
                'NA'   => 'NA (US)',
                'NZAU' => 'NZAU (New Zealand)',
            ],
            'desc_tip'    => true,
        ],
    ];
}

function getVerifoneHostedCartCardPaymentSettingsFields() {
    $fields = [
        'card_settings'               => [
            'title' => __( 'Card payment settings', 'verifone-hosted' ),
            'type'  => 'title',
        ],
        'card_enabled'                => [
            'title'             => __( 'Enable card payment', 'verifone-hosted' ),
            'type'              => 'checkbox',
            'description'       => null,
            'label'             => __( 'Enable card payment', 'verifone-hosted' ),
            'default'           => 'yes',
            'desc_tip'          => true,
            'custom_attributes' => [
                'hides' => '["payment_contract_id", "invoice4u_enabled",  "_3ds_enable", "transaction_type", "abs_installment_enabled","subscription_enabled","fraud_check_enabled"]',
            ],
        ],
        'payment_contract_id'         => [
            'title'       => __( 'Payment provider contract ID', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'Find it on your Payment Provider Contract page for the contract enabling credit card payments.', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => '',
        ],
        '_3ds_enable'                 => [
            'title'             => __( 'Enable card 3DS', 'verifone-hosted' ),
            'type'              => 'checkbox',
            'description'       => __( 'The purpose of 3D-Secure is to safeguard the online payment by applying an additional authentication step of the cardholder before sending an authorization request to the card issuer.', 'verifone-hosted' ),
            'label'             => __( 'Enable card 3DS', 'verifone-hosted' ),
            'default'           => 'yes',
            'desc_tip'          => true,
            'custom_attributes' => [
                'hides' => '["_3ds_contract_id"]', // The hides property accepts a json encoded array of elements to hide if the checkbox is not checked
            ],
        ],
        '_3ds_contract_id'            => [
            'title'             => __( '3DS Contract ID', 'verifone-hosted' ),
            'type'              => 'text',
            'description'       => __( 'The 3DS Contract ID can be found in Verifone Central, under Administration → 3-D Secure Provider Contracts.', 'verifone-hosted' ),
            'default'           => '',
            'desc_tip'          => true,
            'placeholder'       => '',
            'custom_attributes' => [
                'data-level' => 2,
            ]
        ],
        'subscription_enabled'        => [
            'title'             => __( 'Enable subscriptions', 'verifone-hosted' ),
            'type'              => 'checkbox',
            'description'       => null,
            'label'             => __( 'Enable subscriptions', 'verifone-hosted' ),
            'default'           => 'yes',
            'desc_tip'          => true,
            'custom_attributes' => [
                'hides' => '["subscription_id"]',
            ],
        ],
        'subscription_id'             => [
            'title'       => __( 'Subscription ID (Token scopes)', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'Find it under your parent organisation (create new if none available)', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx',
        ],
        'fraud_check_enabled'         => [
            'title'             => __( 'Enable Fraud protection', 'verifone-hosted' ),
            'type'              => 'checkbox',
            'description'       => null,
            'label'             => __( 'Enable Fraud protection', 'verifone-hosted' ),
            'default'           => 'yes',
            'desc_tip'          => true,
            'custom_attributes' => [
                'hides' => '["fraud_check_contract_id"]',
            ],
        ],
        'fraud_check_contract_id'     => [
            'title'       => __( 'Fraud Contract ID', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'Ask your account manager for the fraud contract ID', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx',
        ],
        'transaction_type'            => [
            'title'       => __( 'Transaction type', 'verifone-hosted' ),
            'type'        => 'radio', // The type radio is handled by the custom function generate_radio_html
            'description' => __( 'Make sure that your acquirer supports the payment type you choose:<br>Pre-Auth ( Pre-Auth , Capture now : false )<br>Auth ( Final auth, Capture now : false )<br>Sale ( Final auth, Capture now : true )', 'verifone-hosted' ),
            'label'       => __( 'Transaction type', 'verifone-hosted' ),
            'options'     => [
                'pre_auth' => 'Pre-auth',
                'auth'     => 'Auth',
                'sale'     => 'Sale',
            ],
            'default'     => 'sale',
            'desc_tip'    => true,
        ],
        'invoice4u_enabled'           => [
            'title'             => __( 'Invoice 4U (Israel)', 'verifone-hosted' ),
            'type'              => 'checkbox',
            'label'             => __( 'Invoice 4U (Israel)', 'verifone-hosted' ),
            'default'           => 'no',
            'desc_tip'          => true,
            'custom_attributes' => [
                'hides' => '["invoice4u_receipt_type","send_tax_rates"]',
            ],
        ],
        'send_tax_rates'       => [
            'title'       => __( 'Send tax rates', 'verifone-hosted' ),
            'type'        => 'checkbox',
            'description' => __( 'Enable this if you don\'t want to use the Invoice4u tax settings.', 'verifone-hosted' ),
            'label'       => __( 'Send tax rates', 'verifone-hosted' ),
            'default'     => 'no',
            'desc_tip'    => true,
        ],
        'invoice4u_receipt_type'      => [
            'title'       => __( 'Receipt type', 'verifone-hosted' ),
            'type'        => 'select',
            'description' => __( 'Used to send different invoices to the customer.', 'verifone-hosted' ),
            'label'       => __( 'Receipt type', 'verifone-hosted' ),
            'options'     => [
                'INVOICE'         => 'Invoice',
                'FULL_RECEIPT'    => 'Full receipt',
                'INVOICE_RECEIPT' => 'Invoice receipt',
            ],
            'desc_tip'    => true,
        ],
        'abs_installment_enabled'     => [
            'title'       => __( 'Enable ABS installments (Israel)', 'verifone-hosted' ),
            'type'        => 'checkbox',
            'description' => __( 'Enable if you have a contract with ABS from Israel through Verifone and wish to make use of it in your cart.', 'verifone-hosted' ),
            'label'       => __( 'Enable ABS installments (Israel)', 'verifone-hosted' ),
            'default'     => 'no',
            'desc_tip'    => true,
        ],
        'abs_installment_threshholds' => [
            'title'       => __( 'ABS installment threshholds', 'verifone-hosted' ),
            'type'        => 'input',
            'description' => __( 'Installment threshholds in CSV format (max_order_total,installments)', 'verifone-hosted' ),
            'default'     => '[]',
        ],
    ];
    if ( ! class_exists( 'WC_Subscriptions_Cart' ) ) {
        unset( $fields['subscription_enabled'] );
        unset( $fields['subscription_id'] );
    }

    return $fields;
}

function getVerifoneHostedCartAlternativePaymentOptionsFields() {
    return [
        'apm_settings'                    => [
            'title' => __( 'Alternative payment options', 'verifone-hosted' ),
            'type'  => 'title',
        ],
        'paypal_enabled'                  => [
            'title'             => __( 'PayPal', 'verifone-hosted' ),
            'type'              => 'checkbox',
            'label'             => __( 'PayPal', 'verifone-hosted' ),
            'default'           => 'no',
            'desc_tip'          => true,
            'custom_attributes' => [
                'hides' => '["paypal_contract_id"]', // The hides property accepts a json encoded array of elements to hide if the checkbox is not checked
            ],
        ],
        'paypal_contract_id'              => [
            'title'       => __( 'PayPal payment provider contract ID', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'The ID can be found in Verifone Central, under Administration → Payment Provider Contracts, after selecting the contract available for PayPal as a service provider.', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => '',
        ],
        'apple_pay_enabled'               => [
            'title'             => __( 'Apple Pay', 'verifone-hosted' ),
            'type'              => 'checkbox',
            'label'             => __( 'Apple Pay', 'verifone-hosted' ),
            'default'           => 'no',
            'desc_tip'          => true,
            'custom_attributes' => [
                'hides' => '["apple_pay_sca_compliance_level", "apple_pay_contract_id"]', // The hides property accepts a json encoded array of elements to hide if the checkbox is not checked
            ],
        ],
        'apple_pay_sca_compliance_level'  => [
            'title'       => __( 'SCA (Strong customer authentication)', 'verifone-hosted' ),
            'type'        => 'select',
            'description' => __( 'Select the SCA compliance level required, as instructed by the Verifone team.', 'verifone-hosted' ),
            'label'       => __( 'SCA (Strong customer authentication', 'verifone-hosted' ),
            'options'     => [
                'NONE'      => 'NONE',
                'WALLET'    => 'WALLET',
                'FORCE_3DS' => 'FORCE_3DS',
            ],
            'desc_tip'    => true,
        ],
        'apple_pay_contract_id'           => [
            'title'       => __( 'Apple Pay payment provider contract ID', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'The ID can be found in Verifone Central, under Administration → Payment Provider Contracts, after selecting the contract available for Apple Pay as a service provider.', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => '',
        ],
        'google_pay_enabled'              => [
            'title'             => __( 'Google Pay', 'verifone-hosted' ),
            'type'              => 'checkbox',
            'label'             => __( 'Google Pay', 'verifone-hosted' ),
            'default'           => 'no',
            'desc_tip'          => true,
            'custom_attributes' => [
                'hides' => '["google_pay_sca_compliance_level", "google_pay_contract_id"]', // The hides property accepts a json encoded array of elements to hide if the checkbox is not checked
            ],
        ],
        'google_pay_sca_compliance_level' => [
            'title'       => __( 'SCA (Strong customer authentication', 'verifone-hosted' ),
            'type'        => 'select',
            'description' => __( 'Select the SCA compliance level required, as instructed by the Verifone team.', 'verifone-hosted' ),
            'label'       => __( 'SCA (Strong customer authentication', 'verifone-hosted' ),
            'options'     => [
                'NONE'      => 'NONE',
                'WALLET'    => 'WALLET',
                'FORCE_3DS' => 'FORCE_3DS',
            ],
            'desc_tip'    => true,
        ],
        'google_pay_contract_id'          => [
            'title'       => __( 'Google Pay payment provider contract ID', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'The ID can be found in Verifone Central, under Administration → Payment Provider Contracts, after selecting the contract available for Google Pay as a service provider.', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => '',
        ],
        'mobile_pay_enabled'              => [
            'title'             => __( 'Mobile Pay', 'verifone-hosted' ),
            'type'              => 'checkbox',
            'label'             => __( 'Mobile Pay', 'verifone-hosted' ),
            'default'           => 'no',
            'desc_tip'          => true,
            'custom_attributes' => [
                'hides' => '["mobile_pay_sca_compliance_level", "mobile_pay_contract_id"]', // The hides property accepts a json encoded array of elements to hide if the checkbox is not checked
            ],
        ],
        'mobile_pay_sca_compliance_level' => [
            'title'       => __( 'SCA (Strong customer authentication', 'verifone-hosted' ),
            'type'        => 'select',
            'description' => __( 'Select the SCA compliance level required, as instructed by the Verifone team.', 'verifone-hosted' ),
            'label'       => __( 'SCA (Strong customer authentication', 'verifone-hosted' ),
            'options'     => [
                'NONE'      => 'NONE',
                'WALLET'    => 'WALLET',
                'FORCE_3DS' => 'FORCE_3DS',
            ],
            'desc_tip'    => true,
        ],
        'mobile_pay_contract_id'          => [
            'title'       => 'Mobile Pay payment provider contract ID',
            'type'        => 'text',
            'description' => __( 'The ID can be found in Verifone Central, under Administration → Payment Provider Contracts, after selecting the contract available for Mobile Pay as a service provider.', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => '',
        ],
        'vipps_enabled'                   => [
            'title'             => __( 'Vipps', 'verifone-hosted' ),
            'type'              => 'checkbox',
            'label'             => __( 'Vipps', 'verifone-hosted' ),
            'default'           => 'no',
            'desc_tip'          => true,
            'custom_attributes' => [
                'hides' => '["vipps_sca_compliance_level", "vipps_contract_id"]', // The hides property accepts a json encoded array of elements to hide if the checkbox is not checked
            ],
        ],
        'vipps_sca_compliance_level'      => [
            'title'       => __( 'SCA (Strong customer authentication', 'verifone-hosted' ),
            'type'        => 'select',
            'description' => __( 'Select the SCA compliance level required, as instructed by the Verifone team.', 'verifone-hosted' ),
            'label'       => __( 'SCA (Strong customer authentication', 'verifone-hosted' ),
            'options'     => [
                'NONE'      => 'NONE',
                'WALLET'    => 'WALLET',
                'FORCE_3DS' => 'FORCE_3DS',
            ],
            'desc_tip'    => true,
        ],
        'vipps_contract_id'               => [
            'title'       => 'Vipps payment provider contract ID',
            'type'        => 'text',
            'description' => __( 'The ID can be found in Verifone Central, under Administration → Payment Provider Contracts, after selecting the contract available for Vipps as a service provider.', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => '',
        ],

        'swish_pay_enabled' => [
            'title'    => __( 'Swish', 'verifone-hosted' ),
            'type'     => 'checkbox',
            'label'    => __( 'Swish', 'verifone-hosted' ),
            'default'  => 'no',
            'desc_tip' => true,
        ],
        'klarna_enabled'    => [
            'title'    => __( 'Klarna', 'verifone-hosted' ),
            'type'     => 'checkbox',
            'label'    => __( 'Klarna', 'verifone-hosted' ),
            'default'  => 'no',
            'desc_tip' => true,
        ],
        'gpp2_enabled'      => [
            'title'             => __( 'GPP2', 'verifone-hosted' ),
            'type'              => 'checkbox',
            'label'             => __( 'GPP2', 'verifone-hosted' ),
            'default'           => 'no',
            'desc_tip'          => true,
            'custom_attributes' => [
                'hides' => '["gpp2_contract_id"]', // The hides property accepts a json encoded array of elements to hide if the checkbox is not checked
            ],
        ],
        'gpp2_contract_id'  => [
            'title'       => 'GPP2 payment provider contract ID',
            'type'        => 'text',
            'description' => __( 'The ID can be found in Verifone Central, under Administration → Payment Provider Contracts, after selecting the contract available for GPP2 as a service provider.', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => '',
        ],
    ];
}

function getVerifoneHostedCartDisplaySettingsFields() {
    return [
        'display_settings'       => [
            'title' => __( 'Display settings', 'verifone-hosted' ),
            'type'  => 'title',
        ],
        'payment_type'           => [
            'title'       => __( 'Checkout type', 'verifone-hosted' ),
            'type'        => 'radio', // The type radio is handled by the custom function generate_radio_html
            'description' => __( 'Choose whether you need the Verifone checkout to be displayed as a standalone page or as an iFrame.', 'verifone-hosted' ),
            'label'       => __( 'Checkout type', 'verifone-hosted' ),
            'options'     => [
                'hpp'    => 'Hosted Payment Page',
                'iframe' => 'iFrame',
            ],
            'default'     => 'hpp',
            'desc_tip'    => true,
        ],
        'title'                  => [
            'title'       => __( 'Title', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'Is displayed on the WooCommerce cart to your shoppers, indicating the name of the Verifone checkout/available payment methods.', 'verifone-hosted' ),
            'default'     => __( 'Card Payment', 'verifone-hosted' ),
            'desc_tip'    => true,
        ],
        'description'            => [
            'title'       => __( 'Description', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'Is displayed on the WooCommerce cart to your shoppers, indicating the description of the Verifone checkout/available payment methods.', 'verifone-hosted' ),
            'default'     => __( 'Payments powered by', 'verifone-hosted' ) . ' <a href="https://www.verifone.com/" target="_blank">Verifone</a>',
            'desc_tip'    => true,
        ],
        'checkout_button_text'   => [
            'title'       => __( 'Place order button label', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'Label on the button leading to the Verifone checkout.', 'verifone-hosted' ),
            'default'     => '',
            'desc_tip'    => true,
            'placeholder' => '',
        ],
        'theme_id'               => [
            'title'       => __( 'Theme ID', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'Add an ID to use a theme different from the default Verifone theme. You can find the ID in Verifone Central.', 'verifone-hosted' ),
            'desc_tip'    => true,
        ],
        'overlay_on_place_order' => [
            'title'       => __( 'Enable loading state after placing the order', 'verifone-hosted' ),
            'type'        => 'checkbox',
            'description' => __( 'If enabled, the WooCommerce UI will display a "loading" type of feedback after the "Place order" button is used.', 'verifone-hosted' ),
            'label'       => __( 'Enable loading state after placing the order', 'verifone-hosted' ),
            'default'     => 'yes',
            'desc_tip'    => true,
        ],
    ];
}

function getVerifoneHostedCartAdvancedSettingsFields() {
    return [
        'advanced_settings'         => [
            'title' => __( 'Advanced settings', 'verifone-hosted' ),
            'type'  => 'title',
        ],
        'override_redirect_url'     => [
            'title'       => __( 'Override return url', 'verifone-hosted' ),
            'type'        => 'text',
            'description' => __( 'Please make sure you have webhooks setup in order to keep your orders up to date. If empty, the customer will be redirect back to the store (default functionality). Only VALID URL are allowed!', 'verifone-hosted' ),
            'label'       => __( 'Override return url ', 'verifone-hosted' ),
            'placeholder' => 'https://my-other-site.com/cool-success-page',
            'desc_tip'    => true,
        ],
        'complete_order_on_payment' => [
            'title'       => __( 'Complete order on payment', 'verifone-hosted' ),
            'type'        => 'checkbox',
            'description' => __( 'Change the order status as complete automatically after the payment is successfully made.', 'verifone-hosted' ),
            'label'       => __( 'Complete order on payment', 'verifone-hosted' ),
            'default'     => 'yes',
            'desc_tip'    => true,
        ],
        'curl_verify_ssl'           => [
            'title'       => __( 'Enable cURL verify host and peer', 'verifone-hosted' ),
            'type'        => 'checkbox',
            'description' => __( 'Enable to avoid plugin requests to time out.', 'verifone-hosted' ),
            'label'       => __( 'Enable cURL verify host and peer', 'verifone-hosted' ),
            'default'     => 'no',
            'desc_tip'    => true,
        ],
        'empty_on_place_order'      => [
            'title'       => __( 'Empty shopping cart when placing order', 'verifone-hosted' ),
            'type'        => 'checkbox',
            'description' => __( 'This option will empty the shopping cart when the buyer is redirected to Verifone. Keep unchecked if you want the buyer to be able to recover their cart until they have successfully paid for the order.', 'verifone-hosted' ),
            'label'       => __( 'Empty shopping cart when placing order', 'verifone-hosted' ),
            'default'     => 'no',
            'desc_tip'    => true,
        ],
        'manage_orders'      => [
            'title'       => __( 'Manage orders', 'verifone-hosted' ),
            'type'        => 'checkbox',
            'description' => __( 'Enable this to automatically capture transactions that are changed to "Completed" status and Cancel transactions that are moved to "Canceled" status.', 'verifone-hosted' ),
            'label'       => __( 'Manage orders', 'verifone-hosted' ),
            'default'     => 'no',
            'desc_tip'    => true,
        ],
    ];
}
